@@ -1,9 +1,9 @@
-// Copyright (C) 2003 Free Software Foundation, Inc.
+// Copyright (C) 2003, 2009 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
 // terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2, or (at your option)
+// Free Software Foundation; either version 3, or (at your option)
 // any later version.
 
 // This library is distributed in the hope that it will be useful,
@@ -12,9 +12,14 @@
 // GNU General Public License for more details.
 
 // You should have received a copy of the GNU General Public License along
-// with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-// USA.
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// DR 49 states that cin.rdbuf()->sbumpc() and fgetc(stdin) should be
+// equivalent and interchangable. Currently however, cin.rdbuf()->sungetc()
+// only returns characters that were read with cin.rdbuf()->sbumpc()
+
+// { dg-do run { xfail *-*-* } }
 
 #include <iostream>
 #include <cstdio>
@@ -28,11 +33,16 @@ test01()
 
   wchar_t c1;
   std::wint_t c2;
+  wchar_t c3;
   std::wcin.get(c1);
-  std::wcin.unget();
-  VERIFY( std::wcin.good() );
   c2 = std::fgetwc(stdin);
-  VERIFY( c2 == std::char_traits<wchar_t>::to_int_type(c1) );
+  std::wcin.unget();
+  if (std::wcin.good())
+    {
+      std::wcin.get(c3);
+      VERIFY( std::wcin.good() );
+      VERIFY( c3 == std::char_traits<wchar_t>::to_char_type(c2) );
+    }
 }
 
 int main(void)
